/*
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>. 
*/
package com.thetechnicgear.robotics;
import lejos.hardware.Brick;
import lejos.hardware.BrickFinder;
import lejos.hardware.motor.*;
import lejos.robotics.RegulatedMotor;

/**
 * This program runs on a differential robot that has 62.4mm diameter wheels and a robot track of 122mm.
 * This robot has a pen on the center of rotation and it will draw a square of 40cm. 
 * 
 * @author miguel
 *
 */
public class DrawSquare {
	static double wheelDiameter=6.24;
	static double robotTrack=12.2;
	
	public static void main(String[] args) {
		// Distances and sizes are expressed in centrimetres.
		int squareSize=40;
		double wheelCircunference=DrawSquare.wheelDiameter*Math.PI;
		
		Brick brick=BrickFinder.getDefault();
		
		RegulatedMotor left=new EV3LargeRegulatedMotor(brick.getPort("B"));
		RegulatedMotor right=new EV3LargeRegulatedMotor(brick.getPort("C"));
		
		/* Initialize motors */
		left.setAcceleration(400);
		right.setAcceleration(400);

		left.setSpeed(400);
		right.setSpeed(400);
		
		for(int i=0;i<4;i++) {
			/* Move straight the squareSize centimetres */
			int degrees=(int)Math.round((squareSize/wheelCircunference)*360.0);
			left.rotate(degrees,true);
			right.rotate(degrees);
			
			/* Rotate on the spot */
			degrees=(int)Math.round((((robotTrack*Math.PI)/4.0)/wheelCircunference)*360.0);

			// K is a calibration parametrer to turn the robot.
			double K=0.98;
			degrees=(int)(K*degrees);
			
			left.rotate(-degrees,true);
			right.rotate(degrees);
		}
		
	}

}
