/*
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>. 
*/
package com.thetechnicgear.robotics;
import lejos.hardware.Brick;
import lejos.hardware.BrickFinder;
import lejos.hardware.motor.EV3LargeRegulatedMotor;
import lejos.robotics.RegulatedMotor;
import lejos.robotics.navigation.DifferentialPilot;


/**
 * This program runs on a differential robot that has 62.4mm diameter wheels and a robot track of 115.5mm.
 * This robot has a pen on the center of rotation and it will draw a square of 40cm. 
 * 
 * It is done using the DifferentialPilot class.
 * 
 * @author miguel
 *
 */
public class DrawSquarePilot {

	public static void main(String[] args) {
		Brick brick=BrickFinder.getDefault();
		
		RegulatedMotor leftMotor=new EV3LargeRegulatedMotor(brick.getPort("B"));
		RegulatedMotor rightMotor=new EV3LargeRegulatedMotor(brick.getPort("C"));
		
		DifferentialPilot pilot=new DifferentialPilot(6.24, 11.55, leftMotor, rightMotor);
		
		for(int i=0;i<4;i++) {
			pilot.travel(40);
			pilot.rotate(90);
		}

	}

}
